<?php
namespace Pinpoint\LogoManager\Model\Logo;
use Pinpoint\LogoManager\Model\ResourceModel\Logo\CollectionFactory;
use Magento\Framework\App\Request\DataPersistorInterface;
use Magento\Framework\App\Filesystem\DirectoryList;

/**
 * Class DataProvider
 * @package Pinpoint\LogoManager\Model\Logo
 */
class DataProvider extends \Magento\Ui\DataProvider\AbstractDataProvider
{

    /**
     * @var \Pinpoint\LogoManager\Model\ResourceModel\Logo\Collection
     */
    protected $collection;

    /**
     * @var DataPersistorInterface
     */
    protected $dataPersistor;

    /**
     * @var array
     */
    protected $loadedData;

    /**
     * @var \Magento\Framework\Filesystem
     */
    protected $fileSystem;

    /**
     * @param string $name
     * @param string $primaryFieldName
     * @param string $requestFieldName
     * @param CollectionFactory $collectionFactory
     * @param DataPersistorInterface $dataPersistor
     * @param array $meta
     * @param array $data
     */
    public function __construct(
        $name,
        $primaryFieldName,
        $requestFieldName,
        CollectionFactory $collectionFactory,
        DataPersistorInterface $dataPersistor,
        \Magento\Framework\Filesystem $fileSystem,
        array $meta = [],
        array $data = []
    ) {
        $this->collection = $collectionFactory->create();
        $this->dataPersistor = $dataPersistor;
        $this->fileSystem = $fileSystem;
        parent::__construct($name, $primaryFieldName, $requestFieldName, $meta, $data);
        $this->meta = $this->prepareMeta($this->meta);
    }

    /**
     * Prepares Meta
     *
     * @param array $meta
     * @return array
     */
    public function prepareMeta(array $meta)
    {
        return $meta;
    }

    /**
     * Get data
     *
     * @return array
     */
    public function getData()
    {
        if (isset($this->loadedData)) {
            return $this->loadedData;
        }
        $items = $this->collection->getItems();

        foreach ($items as $item) {
            $filePath = $this->fileSystem->getDirectoryRead(DirectoryList::ROOT)->getAbsolutePath();
            $templateImage = $item->getData('logo');

            if (pathinfo(realpath($_SERVER["DOCUMENT_ROOT"]))['basename'] == 'pub') {
                $item->setData('logo', str_replace('pub/', '', $item->getData('logo')));
            }

            $item->setData('logo', [[
                'url' => $item->getData('logo'),
                'file' => $item->getData('logo'),
                'name' => basename($item->getData('logo')),
                'type' => image_type_to_mime_type(exif_imagetype($filePath . $templateImage)),
                'size'=> filesize($filePath . $templateImage)
            ]]);

            $this->loadedData[$item->getId()] = $item->getData();
        }

        $data = $this->dataPersistor->get('pinpoint_logomanager_logo');
        if (!empty($data)) {
            $item = $this->collection->getNewEmptyItem();
            $item->setData($data);
            $this->loadedData[$item->getId()] = $item->getData();
            $this->dataPersistor->clear('pinpoint_logomanager_logo');
        }

        return $this->loadedData;
    }
}
